neuxml
======

neuxml is an extensible library for reading and writing XML documents in
idiomatic Python. It allows developers to `map predictable XML node
structures <xmlmap.html#general-usage>`_ to
:class:`~neuxml.xmlmap.XmlObject` subclasses, using field definitions to map
`XPath <http://www.w3.org/TR/xpath/>`_ expressions directly to Python
attributes. neuxml also includes an XPath parser in :mod:`neuxml.xpath`.

Contents
--------

.. toctree::
   :maxdepth: 3

   catalog
   xmlmap
   xpath
   Change Log <changelog>

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
